// src/index.ts
async function generateImage(data) {
  const pdf = await import("pdfjs-dist");
  const workerSrc = await import("pdfjs-dist/build/pdf.worker.mjs");
  pdf.GlobalWorkerOptions.workerSrc = workerSrc;
  const canvas = document.createElement("canvas");
  const canvasContext = canvas.getContext("2d");
  const pdfDocument = await pdf.getDocument(data).promise;
  const page = await pdfDocument.getPage(1);
  const viewport = page.getViewport({ scale: 1 });
  canvas.width = viewport.width;
  canvas.height = viewport.height;
  await page.render({
    canvasContext,
    viewport,
    background: "rgba(0,0,0,0)"
  }).promise;
  return new Promise((resolve, reject) => {
    canvas.toBlob((blob) => {
      if (blob) {
        resolve(blob);
      } else {
        reject("Failed to convert canvas to blob");
      }
    });
  });
}
export {
  generateImage
};
//# sourceMappingURL=index.mjs.map